@@ -1,25 +1,11 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2010 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
-import os, sys, time, logging
+import os, time, logging
 
 from optparse import OptionParser
 
@@ -90,6 +76,9 @@ class CliGui(IVisualJobHandler):
 
 class DummyGui(IVisualJobHandler):
 
+    def Info(self, project, rendererClass, profile):
+        pass
+
     def OnHandleJobBegin(self, jobContext):
         pass
 
@@ -154,7 +143,7 @@ def main(showHelp=False):
 
     prjFile = ProjectFile(filename=options.project)
     if not prjFile.Load():
-        logging.error(_(u"cannot load photofilmstrip"))
+        logging.error(_(u"cannot load project"))
         return 6
 
     if options.outputpath:
