@@ -11,9 +11,12 @@ class Aspect:
     ASPECT_4_3 = "4:3"
     ASPECT_3_2 = "3:2"
     ASPECT_16_9 = "16:9"
+    ASPECT_16_10 = "16:10"
 
     @classmethod
     def ToFloat(cls, aspect):
+        if aspect == cls.ASPECT_16_10:
+            return 16.0 / 10.0
         if aspect == cls.ASPECT_16_9:
             return 16.0 / 9.0
         if aspect == cls.ASPECT_4_3:
