@@ -1,23 +1,9 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2011 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import array
 import time
@@ -28,7 +14,6 @@ try:
 except (ImportError, RuntimeError):
     cairo = None
 
-from photofilmstrip.core.OutputProfile import OutputProfile
 from photofilmstrip.core.BaseRenderer import BaseRenderer, FinalizeHandler
 
 
@@ -96,9 +81,6 @@ class CairoRenderer(BaseRenderer):
 
 class PilToCairoFinalizeHandler(FinalizeHandler):
 
-    def UseSmartFinalize(self):
-        return True
-
     def ProcessFinalize(self, pilImg):
         pilImg = pilImg.copy()
         w, h = pilImg.size
