@@ -1,23 +1,9 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2014 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import logging
 import os
@@ -235,7 +221,7 @@ class _GStreamerRenderer(BaseRenderer):
         videoQueue2 = Gst.ElementFactory.make("queue")
         self.pipeline.add(videoQueue2)
 
-        videoEncCaps = self._GetVideoEncoderCaps()
+        videoEncCaps = self._GetVideoEncoderCaps()  # pylint: disable=assignment-from-none
         if videoEncCaps:
             videoEnc.link_filtered(videoQueue2, videoEncCaps)
         else:
@@ -548,9 +534,9 @@ class Mp4X264AAC(_GStreamerRenderer):
             if vEnc is None:
                 msgList.append(_(u"x264-Codec (gstreamer1.0-plugins-ugly) required!"))
 
-            mux = Gst.ElementFactory.find("flvmux")
+            mux = Gst.ElementFactory.find("mp4mux")
             if mux is None:
-                msgList.append(_(u"FLV-Muxer (gstreamer1.0-plugins-good) required!"))
+                msgList.append(_(u"MP4-Muxer (gstreamer1.0-plugins-good) required!"))
 
     @staticmethod
     def GetDefaultProperty(prop):
@@ -570,7 +556,7 @@ class Mp4X264AAC(_GStreamerRenderer):
         return "mp4"
 
     def _GetMux(self):
-        mux = Gst.ElementFactory.make("flvmux")
+        mux = Gst.ElementFactory.make("mp4mux")
         return mux
 
     def _GetAudioEncoder(self):
