@@ -1,28 +1,15 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2008 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import io
 import sys
 import traceback
-import urllib.request, urllib.parse, urllib.error
+import urllib.parse
+import urllib.request
 
 import wx
 from wx.lib.wordwrap import wordwrap
@@ -56,14 +43,18 @@ class DlgBugReport(wx.Dialog):
 
         text = _(u"An unexpected error occured. Do you want to send this bug report to the developers of %s?") % Constants.APP_NAME
 
-        stBmp = wx.StaticBitmap(self, -1, wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_OTHER, (32, 32)))
+        stBmp = wx.StaticBitmap(
+            self, -1,
+            wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_OTHER, (32, 32)))
         stMsg = wx.StaticText(self, -1, wordwrap(text, 300, wx.ClientDC(self)))
 
         szTop = wx.BoxSizer(wx.HORIZONTAL)
         szTop.Add(stBmp, 0, wx.ALIGN_CENTER_VERTICAL | wx.ALL, 8)
         szTop.Add(stMsg, 0, wx.ALL, 8)
 
-        self.tcMsg = wx.TextCtrl(self, -1, msg, style=wx.TE_MULTILINE | wx.TE_READONLY | wx.TE_DONTWRAP)
+        self.tcMsg = wx.TextCtrl(
+            self, -1, msg,
+            style=wx.TE_MULTILINE | wx.TE_READONLY | wx.TE_DONTWRAP)
 
         szCmd = self.CreateSeparatedButtonSizer(wx.YES | wx.NO)
 
@@ -83,28 +74,31 @@ class DlgBugReport(wx.Dialog):
         self.CenterOnParent()
         self.SetFocus()
 
-    def OnYes(self, event):
+    def OnYes(self, event):  # pylint: disable=unused-argument
         info = "\n".join([sys.platform,
                           sys.getdefaultencoding(),
                           sys.getfilesystemencoding(),
                           str(getattr(sys, 'frozen', False))])
-        params = urllib.parse.urlencode({'bugreport': "%s-%s\n\n%s\n%s\n" % (Constants.APP_NAME,
-                                                                       Constants.APP_VERSION_EX,
-                                                                       self.tcMsg.GetValue(),
-                                                                       info)})
+        params = urllib.parse.urlencode(
+            {'bugreport': "%s-%s\n\n%s\n%s\n" % (Constants.APP_NAME,
+                                                 Constants.APP_VERSION_EX,
+                                                 self.tcMsg.GetValue(),
+                                                 info)})
         params = params.encode('utf_8')
         try:
-            fd = urllib.request.urlopen("http://www.photofilmstrip.org/bugreport.php", params)
+            fd = urllib.request.urlopen(
+                "http://www.photofilmstrip.org/bugreport.php", params)
             result = fd.read()
             result = result.decode("utf-8")
         except IOError:
             result = None
 
         if result and result.find("Result 1") != -1:
-            dlg = wx.MessageDialog(self,
-                                   _(u"Bug-Report send. Thank you for your support."),
-                                   _(u"Information"),
-                                   wx.OK | wx.ICON_INFORMATION)
+            dlg = wx.MessageDialog(
+                self,
+                _(u"Bug-Report send. Thank you for your support."),
+                _(u"Information"),
+                wx.OK | wx.ICON_INFORMATION)
             dlg.ShowModal()
             dlg.Destroy()
         else:
