@@ -1,24 +1,10 @@
 # Boa:Dialog:DlgRender
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2008 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import wx
 import wx.adv
@@ -107,8 +93,7 @@ class DlgRender(wx.Dialog):
         # generated method, don't edit
         wx.Dialog.__init__(self, id=wxID_DLGRENDER, name=u'DlgRender',
             parent=prnt, pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
-            style=wx.DEFAULT_DIALOG_STYLE, title=_(u'Render filmstrip'))
-        self.SetClientSize(wx.Size(400, 250))
+            style=wx.DEFAULT_DIALOG_STYLE, title=_(u'Render project'))
 
         self.pnlHdr = PnlDlgHeader(id=wxID_DLGRENDERPNLHDR, name=u'pnlHdr',
             parent=self, pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
@@ -126,7 +111,7 @@ class DlgRender(wx.Dialog):
             id=wxID_DLGRENDERCHOICEFORMAT, name=u'choiceFormat',
             parent=self.pnlSettings, pos=wx.Point(-1, -1),
             size=wx.Size(-1, -1), style=wx.CB_READONLY)
-        self.choiceFormat.SetMinSize(wx.Size(300, -1))
+        self.choiceFormat.SetSizeHints(400, -1)
         self.choiceFormat.Bind(wx.EVT_COMBOBOX, self.OnChoiceFormat,
             id=wxID_DLGRENDERCHOICEFORMAT)
 
@@ -145,8 +130,8 @@ class DlgRender(wx.Dialog):
         self.choiceProfile = wx.Choice(choices=[],
             id=wxID_DLGRENDERCHOICEPROFILE, name=u'choiceProfile',
             parent=self.pnlSettings, pos=wx.Point(-1, -1), size=wx.Size(-1,
-            - 1), style=0)
-        self.choiceProfile.SetMinSize(wx.Size(300, -1))
+            -1), style=0)
+        self.choiceProfile.SetSizeHints(400, -1)
 
         self.cbDraft = wx.CheckBox(id=wxID_DLGRENDERCBDRAFT, label=_(u'Draft'),
             name=u'cbDraft', parent=self.pnlSettings, pos=wx.Point(-1, -1),
@@ -194,7 +179,7 @@ class DlgRender(wx.Dialog):
         self.__SelectProfileByName(settings.GetLastProfile())
 
         self.SetEscapeId(wxID_DLGRENDERCMDCANCEL)
-        self.SetInitialSize(self.GetEffectiveMinSize())
+        self.Fit()
         self.CentreOnParent()
         self.SetFocus()
 
