@@ -1,23 +1,9 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2010 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import os
 import wx
@@ -68,8 +54,8 @@ class PnlWelcome(wx.Panel):
 
         self.cmdNew = wx.BitmapButton(self, -1,
                                       wx.ArtProvider.GetBitmap('PFS_PROJECT_NEW_64'))
-        self.cmdNew.SetToolTip(_(u"Create new project"))
-        self.cmdNew.Bind(wx.EVT_BUTTON, self.__frmMain.OnProjectNew)
+        self.cmdNew.SetToolTip(_(u"Create new slideshow"))
+        self.cmdNew.Bind(wx.EVT_BUTTON, self.__frmMain.OnSlideshow)
 
         self.cmdOpen = wx.BitmapButton(self, -1,
                                        wx.ArtProvider.GetBitmap('PFS_PROJECT_OPEN_64'))
